@@ -52,7 +52,7 @@ known_sources = [
 
     # level 7
 
-    'coqeal', 'mathcomp-abel'
+    'coqeal' #, 'mathcomp-abel'
 
 ]
 
@@ -92,12 +92,13 @@ known_tests = {
     'coquelicot': ('Coquelicot', 'Coquelicot'),
     'coq-unicoq': ('Unicoq', 'Unicoq'),
     'coq-unimath': ('UniMath', 'All'),
+    'elpi': ('Coq', 'Reals'),
     'flocq': ('Flocq', 'Version'),
-    'mathcomp-abel': ('Abel', 'abel'),
+    # 'mathcomp-abel': ('Abel', 'abel'),
     'mathcomp-algebra-tactics': ('mathcomp.algebra_tactics', 'ring'),
     'mathcomp-analysis': ('mathcomp.analysis', 'topology'),
     'mathcomp-bigenough': ('mathcomp', 'bigenough'),
-    'mathcomp-finmap': ('mathcomp.finmap', 'set'),
+    'mathcomp-finmap': ('mathcomp', 'finmap'),
     'mathcomp-multinomials': ('mathcomp.multinomials', 'mpoly'),
     'mathcomp-real-closed': ('mathcomp.real_closed', 'complex'),
     'mathcomp-zify': ('mathcomp', 'zify'),
@@ -124,6 +125,8 @@ def guess_binary_name(srcname):
         return 'lib' + srcname
     if srcname == 'coq':
         return 'libcoq-stdlib'
+    if srcname == 'elpi':
+        return 'libelpi-ocaml'
     if srcname == 'ssreflect':
         return 'libcoq-mathcomp-ssreflect'
     return 'libcoq-' + srcname
@@ -154,7 +157,10 @@ def guess_deps(srcname):
         rawname = dep[0].name
         # we look for a 'libcoq-foo-deadbeef' provided by 'libcoq-foo'
         if not rawname.startswith('libcoq-'):
-            continue
+            if rawname == 'libelpi-ocaml-dev':
+                res.append('elpi')
+            else:
+                continue
         try:
             pkgname = rawname[:rawname.rfind('-')]
             deppkg = cache[pkgname] # read just to detect non-existing
